@@ -1,6 +1,6 @@
 package Net::CLI::Interact;
 {
-  $Net::CLI::Interact::VERSION = '2.123370_002';
+  $Net::CLI::Interact::VERSION = '2.200007_001';
 }
 
 use Moo;
@@ -25,6 +25,10 @@ sub BUILDARGS {
     return { my_args => $params };
 }
 
+sub default_log_categories {
+    return (qw/dialogue dump engine object phrasebook prompt transport/);
+}
+
 has 'log_at' => (
     is => 'rw',
     isa => Maybe[Str],
@@ -36,7 +40,7 @@ sub set_global_log_at {
     my ($self, $level) = @_;
     return unless defined $level and length $level;
     $self->logger->log_flags({
-        map {$_ => $level} qw/dump engine phrasebook prompt transport/
+        map {$_ => $level} default_log_categories()
     });
 }
 
@@ -114,10 +118,6 @@ __END__
 
 Net::CLI::Interact - Toolkit for CLI Automation
 
-=head1 VERSION
-
-version 2.123370_002
-
 =head1 PURPOSE
 
 This module exists to support developers of applications and libraries which
@@ -215,6 +215,14 @@ library will be enabled at that level. Use C<debug> to learn about how the
 library is working internally. See L<Net::CLI::Interact::Logger> for a list of
 the valid level names.
 
+=item C<< timeout => $seconds >>
+
+Configures a default timeout value, in seconds, for interaction with the
+remote device. The default is 10 seconds. You can also set timeout on a
+per-command or per-macro call (see below).
+
+Note that this does not (currently) apply to the initial connection.
+
 =back
 
 =head2 cmd( $command )
@@ -329,7 +337,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2014 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
